@@ -14,7 +14,10 @@ __PACKAGE__->attr('bananas');
 __PACKAGE__->attr([qw/ears eyes/], default => sub { 2 }, chained => 1);
 __PACKAGE__->attr('figs', default => 0);
 __PACKAGE__->attr('friend', {weak => 1});
-__PACKAGE__->attr('heads', {default => 1});
-__PACKAGE__->attr('name');
+__PACKAGE__->attr('heads', {
+    default => 1,
+    filter  => sub { s/\D//g; $_ }
+});
+__PACKAGE__->attr('name', filter  => sub { lc });
 
 1;
\ No newline at end of file
